@@ -44,17 +44,18 @@ def _upload_templates(swift_client, container_name, tht_root, roles_file=None):
 
 
 def create_default_plan(clients, **workflow_input):
+
     workflow_client = clients.workflow_engine
     tripleoclients = clients.tripleoclient
     queue_name = workflow_input['queue_name']
 
-    execution = base.start_workflow(
-        workflow_client,
-        'tripleo.plan_management.v1.create_default_deployment_plan',
-        workflow_input=workflow_input
-    )
-
     with tripleoclients.messaging_websocket(queue_name) as ws:
+        execution = base.start_workflow(
+            workflow_client,
+            'tripleo.plan_management.v1.create_default_deployment_plan',
+            workflow_input=workflow_input
+        )
+
         for payload in base.wait_for_messages(workflow_client, ws, execution,
                                               _WORKFLOW_TIMEOUT):
             if 'message' in payload:
@@ -72,12 +73,12 @@ def _create_update_deployment_plan(clients, workflow, **workflow_input):
     tripleoclients = clients.tripleoclient
     queue_name = workflow_input['queue_name']
 
-    execution = base.start_workflow(
-        workflow_client, workflow,
-        workflow_input=workflow_input
-    )
-
     with tripleoclients.messaging_websocket(queue_name) as ws:
+        execution = base.start_workflow(
+            workflow_client, workflow,
+            workflow_input=workflow_input
+        )
+
         for payload in base.wait_for_messages(workflow_client, ws, execution,
                                               _WORKFLOW_TIMEOUT):
             if 'message' in payload:
@@ -92,7 +93,10 @@ def create_deployment_plan(clients, **workflow_input):
         **workflow_input)
 
     if payload['status'] == 'SUCCESS':
-        print("Plan created")
+        if 'use_default_templates' in workflow_input:
+            print("Default plan created")
+        else:
+            print("Plan created")
     else:
         raise exceptions.WorkflowServiceError(
             'Exception creating plan: {}'.format(payload['message']))
@@ -182,4 +186,29 @@ def update_plan_from_templates(clients, name, tht_root, roles_file=None,
     _upload_templates(swift_client, name, tht_root, roles_file)
     update_deployment_plan(clients, container=name,
                            queue_name=str(uuid.uuid4()),
-                           generate_passwords=generate_passwords)
+                           generate_passwords=generate_passwords,
+                           source_url=None)
+
+
+def export_deployment_plan(clients, **workflow_input):
+    workflow_client = clients.workflow_engine
+    tripleoclients = clients.tripleoclient
+    queue_name = workflow_input['queue_name']
+
+    execution = base.start_workflow(
+        workflow_client,
+        'tripleo.plan_management.v1.export_deployment_plan',
+        workflow_input=workflow_input
+    )
+
+    with tripleoclients.messaging_websocket(queue_name) as ws:
+        for payload in base.wait_for_messages(workflow_client, ws, execution,
+                                              _WORKFLOW_TIMEOUT):
+            if 'message' in payload:
+                print(payload['message'])
+
+    if payload['status'] == 'SUCCESS':
+        return payload['tempurl']
+    else:
+        raise exceptions.WorkflowServiceError(
+            'Exception exporting plan: {}'.format(payload['message']))
